==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/collection/request/Msdyn_aifptrainingdocumentCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Msdyn_aifptrainingdocument;
import microsoft.dynamics.crm.entity.request.AnnotationRequest;
import microsoft.dynamics.crm.entity.request.AsyncoperationRequest;
import microsoft.dynamics.crm.entity.request.BulkdeletefailureRequest;
import microsoft.dynamics.crm.entity.request.MailboxtrackingfolderRequest;
import microsoft.dynamics.crm.entity.request.Msdyn_aifptrainingdocumentRequest;
import microsoft.dynamics.crm.entity.request.PrincipalobjectattributeaccessRequest;
import microsoft.dynamics.crm.entity.request.ProcesssessionRequest;
import microsoft.dynamics.crm.entity.request.SyncerrorRequest;
import microsoft.dynamics.crm.schema.SchemaInfo;

public class Msdyn_aifptrainingdocumentCollectionRequest extends CollectionPageEntityRequest<Msdyn_aifptrainingdocument, Msdyn_aifptrainingdocumentRequest>{

    protected ContextPath contextPath;

    public Msdyn_aifptrainingdocumentCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Msdyn_aifptrainingdocument.class, cp -> new Msdyn_aifptrainingdocumentRequest(cp, Optional.empty()), SchemaInfo.INSTANCE, value);
        this.contextPath = contextPath;
    }

    public SyncerrorCollectionRequest msdyn_aifptrainingdocument_SyncErrors() {
        return new SyncerrorCollectionRequest(contextPath.addSegment("msdyn_aifptrainingdocument_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest msdyn_aifptrainingdocument_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("msdyn_aifptrainingdocument_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest msdyn_aifptrainingdocument_AsyncOperations() {
        return new AsyncoperationCollectionRequest(contextPath.addSegment("msdyn_aifptrainingdocument_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest msdyn_aifptrainingdocument_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("msdyn_aifptrainingdocument_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public MailboxtrackingfolderCollectionRequest msdyn_aifptrainingdocument_MailboxTrackingFolders() {
        return new MailboxtrackingfolderCollectionRequest(contextPath.addSegment("msdyn_aifptrainingdocument_MailboxTrackingFolders"), Optional.empty());
    }

    public MailboxtrackingfolderRequest msdyn_aifptrainingdocument_MailboxTrackingFolders(String mailboxtrackingfolderid) {
        return new MailboxtrackingfolderRequest(contextPath.addSegment("msdyn_aifptrainingdocument_MailboxTrackingFolders").addKeys(new NameValue(mailboxtrackingfolderid.toString())), Optional.empty());
    }

    public ProcesssessionCollectionRequest msdyn_aifptrainingdocument_ProcessSession() {
        return new ProcesssessionCollectionRequest(contextPath.addSegment("msdyn_aifptrainingdocument_ProcessSession"), Optional.empty());
    }

    public ProcesssessionRequest msdyn_aifptrainingdocument_ProcessSession(String processsessionid) {
        return new ProcesssessionRequest(contextPath.addSegment("msdyn_aifptrainingdocument_ProcessSession").addKeys(new NameValue(processsessionid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest msdyn_aifptrainingdocument_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(contextPath.addSegment("msdyn_aifptrainingdocument_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest msdyn_aifptrainingdocument_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("msdyn_aifptrainingdocument_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public PrincipalobjectattributeaccessCollectionRequest msdyn_aifptrainingdocument_PrincipalObjectAttributeAccesses() {
        return new PrincipalobjectattributeaccessCollectionRequest(contextPath.addSegment("msdyn_aifptrainingdocument_PrincipalObjectAttributeAccesses"), Optional.empty());
    }

    public PrincipalobjectattributeaccessRequest msdyn_aifptrainingdocument_PrincipalObjectAttributeAccesses(String principalobjectattributeaccessid) {
        return new PrincipalobjectattributeaccessRequest(contextPath.addSegment("msdyn_aifptrainingdocument_PrincipalObjectAttributeAccesses").addKeys(new NameValue(principalobjectattributeaccessid.toString())), Optional.empty());
    }

    public AnnotationCollectionRequest msdyn_aifptrainingdocument_Annotations() {
        return new AnnotationCollectionRequest(contextPath.addSegment("msdyn_aifptrainingdocument_Annotations"), Optional.empty());
    }

    public AnnotationRequest msdyn_aifptrainingdocument_Annotations(String annotationid) {
        return new AnnotationRequest(contextPath.addSegment("msdyn_aifptrainingdocument_Annotations").addKeys(new NameValue(annotationid.toString())), Optional.empty());
    }

}

==> odata-client-microsoft-dynamics-0.1.39-sources.jar: microsoft/dynamics/crm/entity/collection/request/Msdyn_aifptrainingdocumentCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Msdyn_aifptrainingdocument;
import microsoft.dynamics.crm.entity.request.AnnotationRequest;
import microsoft.dynamics.crm.entity.request.AsyncoperationRequest;
import microsoft.dynamics.crm.entity.request.BulkdeletefailureRequest;
import microsoft.dynamics.crm.entity.request.MailboxtrackingfolderRequest;
import microsoft.dynamics.crm.entity.request.Msdyn_aifptrainingdocumentRequest;
import microsoft.dynamics.crm.entity.request.PrincipalobjectattributeaccessRequest;
import microsoft.dynamics.crm.entity.request.ProcesssessionRequest;
import microsoft.dynamics.crm.entity.request.SyncerrorRequest;

public class Msdyn_aifptrainingdocumentCollectionRequest extends CollectionPageEntityRequest<Msdyn_aifptrainingdocument, Msdyn_aifptrainingdocumentRequest>{

    protected ContextPath contextPath;

    public Msdyn_aifptrainingdocumentCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Msdyn_aifptrainingdocument.class, cp -> new Msdyn_aifptrainingdocumentRequest(cp, Optional.empty()), value);
        this.contextPath = contextPath;
    }

    public SyncerrorCollectionRequest msdyn_aifptrainingdocument_SyncErrors() {
        return new SyncerrorCollectionRequest(contextPath.addSegment("msdyn_aifptrainingdocument_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest msdyn_aifptrainingdocument_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("msdyn_aifptrainingdocument_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest msdyn_aifptrainingdocument_AsyncOperations() {
        return new AsyncoperationCollectionRequest(contextPath.addSegment("msdyn_aifptrainingdocument_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest msdyn_aifptrainingdocument_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("msdyn_aifptrainingdocument_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public MailboxtrackingfolderCollectionRequest msdyn_aifptrainingdocument_MailboxTrackingFolders() {
        return new MailboxtrackingfolderCollectionRequest(contextPath.addSegment("msdyn_aifptrainingdocument_MailboxTrackingFolders"), Optional.empty());
    }

    public MailboxtrackingfolderRequest msdyn_aifptrainingdocument_MailboxTrackingFolders(String mailboxtrackingfolderid) {
        return new MailboxtrackingfolderRequest(contextPath.addSegment("msdyn_aifptrainingdocument_MailboxTrackingFolders").addKeys(new NameValue(mailboxtrackingfolderid.toString())), Optional.empty());
    }

    public ProcesssessionCollectionRequest msdyn_aifptrainingdocument_ProcessSession() {
        return new ProcesssessionCollectionRequest(contextPath.addSegment("msdyn_aifptrainingdocument_ProcessSession"), Optional.empty());
    }

    public ProcesssessionRequest msdyn_aifptrainingdocument_ProcessSession(String processsessionid) {
        return new ProcesssessionRequest(contextPath.addSegment("msdyn_aifptrainingdocument_ProcessSession").addKeys(new NameValue(processsessionid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest msdyn_aifptrainingdocument_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(contextPath.addSegment("msdyn_aifptrainingdocument_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest msdyn_aifptrainingdocument_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("msdyn_aifptrainingdocument_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public PrincipalobjectattributeaccessCollectionRequest msdyn_aifptrainingdocument_PrincipalObjectAttributeAccesses() {
        return new PrincipalobjectattributeaccessCollectionRequest(contextPath.addSegment("msdyn_aifptrainingdocument_PrincipalObjectAttributeAccesses"), Optional.empty());
    }

    public PrincipalobjectattributeaccessRequest msdyn_aifptrainingdocument_PrincipalObjectAttributeAccesses(String principalobjectattributeaccessid) {
        return new PrincipalobjectattributeaccessRequest(contextPath.addSegment("msdyn_aifptrainingdocument_PrincipalObjectAttributeAccesses").addKeys(new NameValue(principalobjectattributeaccessid.toString())), Optional.empty());
    }

    public AnnotationCollectionRequest msdyn_aifptrainingdocument_Annotations() {
        return new AnnotationCollectionRequest(contextPath.addSegment("msdyn_aifptrainingdocument_Annotations"), Optional.empty());
    }

    public AnnotationRequest msdyn_aifptrainingdocument_Annotations(String annotationid) {
        return new AnnotationRequest(contextPath.addSegment("msdyn_aifptrainingdocument_Annotations").addKeys(new NameValue(annotationid.toString())), Optional.empty());
    }

}
